oceantide.input package
=======================

Submodules
----------

oceantide.input.oceantide module
--------------------------------

.. automodule:: oceantide.input.oceantide
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.input.otis\_atlas\_netcdf module
------------------------------------------

.. automodule:: oceantide.input.otis_atlas_netcdf
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.input.otis\_binary module
-----------------------------------

.. automodule:: oceantide.input.otis_binary
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.input.otis\_netcdf module
-----------------------------------

.. automodule:: oceantide.input.otis_netcdf
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: oceantide.input
   :members:
   :undoc-members:
   :show-inheritance:
